==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/AzureWorkloadAutoProtectionIntentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.BackupManagementType
import com.pulumi.azurenative.recoveryservices.kotlin.enums.ProtectionStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Azure Recovery Services Vault specific protection intent item.
 * @property backupManagementType Type of backup management for the backed up item.
 * @property itemId ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
 * @property policyId ID of the backup policy with which this item is backed up.
 * @property protectionIntentItemType backup protectionIntent type.
 * Expected value is 'AzureWorkloadAutoProtectionIntent'.
 * @property protectionState Backup state of this backup item.
 * @property sourceResourceId ARM ID of the resource to be backed up.
 */
public data class AzureWorkloadAutoProtectionIntentArgs(
    public val backupManagementType: Output<Either<String, BackupManagementType>>? = null,
    public val itemId: Output<String>? = null,
    public val policyId: Output<String>? = null,
    public val protectionIntentItemType: Output<String>,
    public val protectionState: Output<Either<String, ProtectionStatus>>? = null,
    public val sourceResourceId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs =
        com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs.builder()
            .backupManagementType(
                backupManagementType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .itemId(itemId?.applyValue({ args0 -> args0 }))
            .policyId(policyId?.applyValue({ args0 -> args0 }))
            .protectionIntentItemType(protectionIntentItemType.applyValue({ args0 -> args0 }))
            .protectionState(
                protectionState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .sourceResourceId(sourceResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureWorkloadAutoProtectionIntentArgs].
 */
@PulumiTagMarker
public class AzureWorkloadAutoProtectionIntentArgsBuilder internal constructor() {
    private var backupManagementType: Output<Either<String, BackupManagementType>>? = null

    private var itemId: Output<String>? = null

    private var policyId: Output<String>? = null

    private var protectionIntentItemType: Output<String>? = null

    private var protectionState: Output<Either<String, ProtectionStatus>>? = null

    private var sourceResourceId: Output<String>? = null

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("tnewfubqndslgbct")
    public suspend fun backupManagementType(`value`: Output<Either<String, BackupManagementType>>) {
        this.backupManagementType = value
    }

    /**
     * @param value ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
     */
    @JvmName("qxktvlwavwdkxttj")
    public suspend fun itemId(`value`: Output<String>) {
        this.itemId = value
    }

    /**
     * @param value ID of the backup policy with which this item is backed up.
     */
    @JvmName("uelkyxcsojtlstxn")
    public suspend fun policyId(`value`: Output<String>) {
        this.policyId = value
    }

    /**
     * @param value backup protectionIntent type.
     * Expected value is 'AzureWorkloadAutoProtectionIntent'.
     */
    @JvmName("fipvskfxpwpfjwqh")
    public suspend fun protectionIntentItemType(`value`: Output<String>) {
        this.protectionIntentItemType = value
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("vtpqqysacavddnbb")
    public suspend fun protectionState(`value`: Output<Either<String, ProtectionStatus>>) {
        this.protectionState = value
    }

    /**
     * @param value ARM ID of the resource to be backed up.
     */
    @JvmName("hvjooarpbtafoywf")
    public suspend fun sourceResourceId(`value`: Output<String>) {
        this.sourceResourceId = value
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("elsidlnenvxtpfnj")
    public suspend fun backupManagementType(`value`: Either<String, BackupManagementType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("btyjywqbiwjgggcs")
    public fun backupManagementType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("egbqbxhsfuvtjocl")
    public fun backupManagementType(`value`: BackupManagementType) {
        val toBeMapped = Either.ofRight<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
     */
    @JvmName("tnmnryjsmsiqwhbh")
    public suspend fun itemId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.itemId = mapped
    }

    /**
     * @param value ID of the backup policy with which this item is backed up.
     */
    @JvmName("lqrulksvbyrmamth")
    public suspend fun policyId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policyId = mapped
    }

    /**
     * @param value backup protectionIntent type.
     * Expected value is 'AzureWorkloadAutoProtectionIntent'.
     */
    @JvmName("bkmyklmwqvcseyjc")
    public suspend fun protectionIntentItemType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionIntentItemType = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("bcvuwjbvcsiaceys")
    public suspend fun protectionState(`value`: Either<String, ProtectionStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("kqychcpqatbvcwnm")
    public fun protectionState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ProtectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("vduuhphxkjvxwydj")
    public fun protectionState(`value`: ProtectionStatus) {
        val toBeMapped = Either.ofRight<String, ProtectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value ARM ID of the resource to be backed up.
     */
    @JvmName("sdocydxsbgdlfftt")
    public suspend fun sourceResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceResourceId = mapped
    }

    internal fun build(): AzureWorkloadAutoProtectionIntentArgs =
        AzureWorkloadAutoProtectionIntentArgs(
            backupManagementType = backupManagementType,
            itemId = itemId,
            policyId = policyId,
            protectionIntentItemType = protectionIntentItemType ?: throw
                PulumiNullFieldException("protectionIntentItemType"),
            protectionState = protectionState,
            sourceResourceId = sourceResourceId,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/AzureWorkloadAutoProtectionIntentArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.BackupManagementType
import com.pulumi.azurenative.recoveryservices.kotlin.enums.ProtectionStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Azure Recovery Services Vault specific protection intent item.
 * @property backupManagementType Type of backup management for the backed up item.
 * @property itemId ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
 * @property policyId ID of the backup policy with which this item is backed up.
 * @property protectionIntentItemType backup protectionIntent type.
 * Expected value is 'AzureWorkloadAutoProtectionIntent'.
 * @property protectionState Backup state of this backup item.
 * @property sourceResourceId ARM ID of the resource to be backed up.
 */
public data class AzureWorkloadAutoProtectionIntentArgs(
    public val backupManagementType: Output<Either<String, BackupManagementType>>? = null,
    public val itemId: Output<String>? = null,
    public val policyId: Output<String>? = null,
    public val protectionIntentItemType: Output<String>,
    public val protectionState: Output<Either<String, ProtectionStatus>>? = null,
    public val sourceResourceId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs =
        com.pulumi.azurenative.recoveryservices.inputs.AzureWorkloadAutoProtectionIntentArgs.builder()
            .backupManagementType(
                backupManagementType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .itemId(itemId?.applyValue({ args0 -> args0 }))
            .policyId(policyId?.applyValue({ args0 -> args0 }))
            .protectionIntentItemType(protectionIntentItemType.applyValue({ args0 -> args0 }))
            .protectionState(
                protectionState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .sourceResourceId(sourceResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureWorkloadAutoProtectionIntentArgs].
 */
@PulumiTagMarker
public class AzureWorkloadAutoProtectionIntentArgsBuilder internal constructor() {
    private var backupManagementType: Output<Either<String, BackupManagementType>>? = null

    private var itemId: Output<String>? = null

    private var policyId: Output<String>? = null

    private var protectionIntentItemType: Output<String>? = null

    private var protectionState: Output<Either<String, ProtectionStatus>>? = null

    private var sourceResourceId: Output<String>? = null

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("apuqhofiloeyrkya")
    public suspend fun backupManagementType(`value`: Output<Either<String, BackupManagementType>>) {
        this.backupManagementType = value
    }

    /**
     * @param value ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
     */
    @JvmName("nbnywblfyyiprdtw")
    public suspend fun itemId(`value`: Output<String>) {
        this.itemId = value
    }

    /**
     * @param value ID of the backup policy with which this item is backed up.
     */
    @JvmName("sybljoixdjbnlwpo")
    public suspend fun policyId(`value`: Output<String>) {
        this.policyId = value
    }

    /**
     * @param value backup protectionIntent type.
     * Expected value is 'AzureWorkloadAutoProtectionIntent'.
     */
    @JvmName("vtwcjjmvmqeiuvxv")
    public suspend fun protectionIntentItemType(`value`: Output<String>) {
        this.protectionIntentItemType = value
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("sygebrkoogfjjuev")
    public suspend fun protectionState(`value`: Output<Either<String, ProtectionStatus>>) {
        this.protectionState = value
    }

    /**
     * @param value ARM ID of the resource to be backed up.
     */
    @JvmName("bxfyckfmghiwhcyu")
    public suspend fun sourceResourceId(`value`: Output<String>) {
        this.sourceResourceId = value
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("eqmhgnxxwfqdhysc")
    public suspend fun backupManagementType(`value`: Either<String, BackupManagementType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("glpoghivafscawwe")
    public fun backupManagementType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the backed up item.
     */
    @JvmName("mskspwncagdwjynh")
    public fun backupManagementType(`value`: BackupManagementType) {
        val toBeMapped = Either.ofRight<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value ID of the item which is getting protected, In case of Azure Vm , it is ProtectedItemId
     */
    @JvmName("nmfnajklaryuvuwh")
    public suspend fun itemId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.itemId = mapped
    }

    /**
     * @param value ID of the backup policy with which this item is backed up.
     */
    @JvmName("mrraipqfaylevlqx")
    public suspend fun policyId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.policyId = mapped
    }

    /**
     * @param value backup protectionIntent type.
     * Expected value is 'AzureWorkloadAutoProtectionIntent'.
     */
    @JvmName("vmbeuqtgxsafgvre")
    public suspend fun protectionIntentItemType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionIntentItemType = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("fybsfyynxmunmenq")
    public suspend fun protectionState(`value`: Either<String, ProtectionStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("bcyivwdcrpwhirfo")
    public fun protectionState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ProtectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value Backup state of this backup item.
     */
    @JvmName("yiiexyuidmmykyim")
    public fun protectionState(`value`: ProtectionStatus) {
        val toBeMapped = Either.ofRight<String, ProtectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protectionState = mapped
    }

    /**
     * @param value ARM ID of the resource to be backed up.
     */
    @JvmName("asqugioffedrgmyd")
    public suspend fun sourceResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceResourceId = mapped
    }

    internal fun build(): AzureWorkloadAutoProtectionIntentArgs =
        AzureWorkloadAutoProtectionIntentArgs(
            backupManagementType = backupManagementType,
            itemId = itemId,
            policyId = policyId,
            protectionIntentItemType = protectionIntentItemType ?: throw
                PulumiNullFieldException("protectionIntentItemType"),
            protectionState = protectionState,
            sourceResourceId = sourceResourceId,
        )
}
